# WoW BIS Rolls

[![PyPI - Version](https://img.shields.io/pypi/v/wow-bis-rolls.svg)](https://pypi.org/project/wow-bis-rolls)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/wow-bis-rolls.svg)](https://pypi.org/project/wow-bis-rolls)

-----

## Table of Contents

- [Installation](#installation)
- [Usage](#usage)
- [License](#license)

## Installation

```console
pip install wow-bis-rolls
```

## Usage

```
$ bis-rolls rolls.json
Wartorious won BiS on [Dark Edge of Insanity]
Angelnomore won BiS on [Dark Storm Gauntlets]
Byornski won BiS on [Carapace of the Old God]
Kongtikki won BiS on [Husk of the Old God]
Freewrath won BiS on [Husk of the Old God]
Tornwulf won BiS on [Intact Viscera]
Iskhiaro won BiS on [Intact Peritoneum]
Inarra won BiS on [Intact Entrails]
```

## License

`wow-bis-rolls` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
